package magasin;

import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

public class PanierImpl implements Panier {
	private Map<Produit, LigneDeCommande> lignes;
	private boolean valide;

	PanierImpl() {
		lignes = new HashMap<Produit, LigneDeCommande>();
		valide = false;
	}

	LigneDeCommandeImpl ligneParProduit(Produit p) {
		LigneDeCommandeImpl ldc = (LigneDeCommandeImpl)lignes.get(p);
		if (ldc == null) {
			ldc = new LigneDeCommandeImpl(p, 0);
			lignes.put(p, ldc);
		}
		return ldc;
	}

	@Override
	public void ajouterProduit(Produit p, int q) {
		if (!valide) {
			LigneDeCommandeImpl ldc = ligneParProduit(p);
			ldc.modifierQuantite(q + ldc.quantite());
		}
	}

	@Override
	public void modifierQuantiteProduit(Produit p, int q) {
		if (!valide) {
			ligneParProduit(p).modifierQuantite(q);
		}
	}

	@Override
	public void supprimerProduit(Produit p) {
		if (!valide && lignes.containsKey(p)) {
			lignes.remove(p);
		}
	}

	@Override
	public double calculerPrix() {
		double res = 0;
		for (LigneDeCommande ldc : lignesDeCommande()) {
			res += ldc.calculerPrix();
		}
		return res;
	}

	@Override
	public void valider() {
		valide = true;
	}

	@Override
	public Collection<LigneDeCommande> lignesDeCommande() {
		return Collections.unmodifiableCollection(lignes.values());
	}
}
